@@ -8,7 +8,6 @@ our @ISA = qw{ Module::Build };
 
 use Carp;
 
-
 sub ACTION_authortest {
     my ( $self ) = @_;		# Arguments unused
 
@@ -81,7 +80,9 @@ C<--test_files> argument.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Win32API-File-Time>,
+L<https://github.com/trwyant/perl-Win32API-File-Time/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -89,7 +90,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010, 2016-2017, 2019 Thomas R. Wyant, III
+Copyright (C) 2009-2010, 2016-2017, 2019-2021 Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
